@@ -1,6 +1,7 @@
 """This defines a basic wsgi application that provides RESTful routing."""
 
 from werkzeug.exceptions import MethodNotAllowed
+from werkzeug.wrappers import Request
 
 
 class RestApplication(object):
@@ -19,11 +20,15 @@ class RestApplication(object):
         found in the `wsgi` module.
     """
 
-    def __init__(self, url_map):
+    def __init__(self, url_map, pre_hooks=None, post_hooks=None):
 
         self.url_map = url_map
+        self.pre_hooks = pre_hooks or []
+        self.post_hooks = post_hooks or []
 
-    def __call__(self, request):
+    def __call__(self, environ, start_response):
+
+        request = Request(environ)
 
         # Werkzeug documentation shows, but does not promise, that request
         # methods are upper case already. Since it isn't explicitly promised
@@ -40,12 +45,21 @@ class RestApplication(object):
         # match found.
         Endpoint, kwargs = urls.match()
 
-        handler = Endpoint()
+        handler_endpoint = Endpoint()
 
-        if hasattr(handler, verb):
+        try:
+            handler_method = getattr(handler_endpoint, verb)
 
-            return getattr(handler, verb)(request, **kwargs)
+        except AttributeError:
+            raise MethodNotAllowed()
 
-        # Reaching this point means the url matches a route, but did not have
-        # a method matching the request. Assume `MethodNotAllowed`.
-        raise MethodNotAllowed()
+        for hook in self.pre_hooks:
+            hook(request)
+
+        response = handler_method(request, **kwargs)
+
+        for hook in self.post_hooks:
+
+            hook(request, response)
+
+        return response
