@@ -29,10 +29,9 @@ class TestApplication(unittest.TestCase):
 
     def test_verb_routing_success(self):
 
-        request = Request(EnvironBuilder(path='/',
-                                         method='GET').get_environ())
+        environ = EnvironBuilder(path='/', method='GET').get_environ()
 
-        response = self.application(request)
+        response = self.application(environ, lambda: None)
 
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.data, "TEST")
@@ -40,17 +39,16 @@ class TestApplication(unittest.TestCase):
     def test_verb_routing_failure(self):
 
         try:
-            request = Request(EnvironBuilder(path='/',
-                                             method='POST').get_environ())
-            self.application(request)
+            environ = EnvironBuilder(path='/', method='POST').get_environ()
+            self.application(environ, lambda: None)
         except MethodNotAllowed:
             return
 
     def test_route_not_found(self):
 
         try:
-            request = Request(EnvironBuilder(path='/notfound',
-                                             method='GET').get_environ())
-            self.application(request)
+            environ = EnvironBuilder(path='/notfound',
+                                     method='GET').get_environ()
+            self.application(environ, lambda: None)
         except NotFound:
             return
